Subprocess handler — BCI-Framework documentation

# Subprocess handler

class `bci_framework.framework.subprocess_handler.` `BrythonLogging`

  Log messages from Brython.

  `feed`(level: int, message: str, lineNumber: int, sourceID: str) → None

    Concatenae messages.

  `readline`(timeout: Optional[int] = None) → str

    Get mesage from JavaScriptConsole.

class `bci_framework.framework.subprocess_handler.` `StimuliSubprocess`

  Connect with Brython logs.

class `bci_framework.framework.subprocess_handler.` `VisualizationSubprocess`

  Define matplotlib properties and start the auto-resizer.

`bci_framework.framework.subprocess_handler.` `run_subprocess`(call: Command) → subprocess.Popen

  Run a python script with non blocking debugger installed.